<?php

/*********************************************************************

 アルバムレスポンスプラグイン (2016/03/07)

 freo.jp
 customize by 32877(http://32877.xii.jp)

*********************************************************************/

//外部ファイル読み込み
require_once FREO_MAIN_DIR . 'freo/plugins/security_plugin_albumres.php';
require_once FREO_MAIN_DIR . 'freo/plugins/associate_plugin_album.php';
require_once FREO_MAIN_DIR . 'freo/plugins/security_plugin_album.php';
require_once FREO_MAIN_DIR . 'freo/plugins/filter_plugin_album.php';

/* メイン処理 */
function freo_page_albumres()
{
	global $freo;

	switch ($_REQUEST['freo']['work']) {
		case 'setup':
			freo_page_albumres_setup();
			break;
		case 'setup_execute':
			freo_page_albumres_setup_execute();
			break;
		case 'admin':
			freo_page_albumres_admin();
			break;
		case 'admin_form':
			freo_page_albumres_admin_form();
			break;
		case 'admin_post':
			freo_page_albumres_admin_post();
			break;
		case 'form':
			freo_page_albumres_form();
			break;
		case 'post':
			freo_page_albumres_post();
			break;
		case 'admin_delete':
			freo_page_albumres_admin_delete();
			break;
		default:
			freo_page_albumres_default();
	}

	return;
}

/* セットアップ */
function freo_page_albumres_setup()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (!freo_token('check')) {
			$freo->smarty->append('errors', '不正なアクセスです。');
		}

		//エラー確認
		if (!$freo->smarty->get_template_vars('errors')) {
			freo_redirect('albumres/setup_execute?freo%5Btoken%5D=' . freo_token('create'), true);
		}
	}

	//データ割当
	$freo->smarty->assign(array(
		'token'       => freo_token('create'),
		'plugin_id'   => 'albumres',
		'plugin_name' => FREO_PLUGIN_ALBUMRES_NAME
	));

	//データ出力
	freo_output('plugins/setup.html');

	return;
}

/* セットアップ | セットアップ実行 */
function freo_page_albumres_setup_execute()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('setup?error=1', true);
	}

	//データベーステーブル存在検証
	if (FREO_DATABASE_TYPE == 'mysql') {
		$query = 'SHOW TABLES';
	} else {
		$query = 'SELECT name FROM sqlite_master WHERE type = \'table\'';
	}
	$stmt = $freo->pdo->query($query);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$table = array();
	while ($data = $stmt->fetch(PDO::FETCH_NUM)) {
		$table[$data[0]] = true;
	}

	//データベーステーブル定義
	if (FREO_DATABASE_TYPE == 'mysql') {
		$queries = array(
			'plugin_albumreses' => '(
				id INT UNSIGNED NOT NULL AUTO_INCREMENT,
				created DATETIME NOT NULL,
				modified DATETIME NOT NULL,
				name VARCHAR(255),
				url TEXT,
				mail TEXT,
				text TEXT NOT NULL,
				album_id INT UNSIGNED,
				option01    TEXT,
				option02    TEXT,
				option03    TEXT,
				option04    TEXT,
				option05    TEXT,
				option06    TEXT,
				option07    TEXT,
				option08    TEXT,
				option09    TEXT,
				option10    TEXT,
				ip VARCHAR(80) NOT NULL,
				user_id VARCHAR(255),
				restriction VARCHAR(20),
				PRIMARY KEY(id)
			)'
		);
	} else {
		$queries = array(
			'plugin_albumreses' => '(
				id INTEGER,
				created DATETIME NOT NULL,
				modified DATETIME NOT NULL,
				name VARCHAR,
				url TEXT,
				mail TEXT,
				text TEXT NOT NULL,
				album_id INTEGER,
				option01    TEXT,
				option02    TEXT,
				option03    TEXT,
				option04    TEXT,
				option05    TEXT,
				option06    TEXT,
				option07    TEXT,
				option08    TEXT,
				option09    TEXT,
				option10    TEXT,
				ip VARCHAR NOT NULL, 
				user_id VARCHAR,
				restriction VARCHAR,
				PRIMARY KEY(id)
			)'
		);
	}

	//データベーステーブル作成
	foreach ($queries as $name => $query) {
		if (empty($table[FREO_DATABASE_PREFIX . $name])) {
			$stmt = $freo->pdo->query('CREATE TABLE ' . FREO_DATABASE_PREFIX . $name . $query);
			if (!$stmt) {
				freo_error($freo->pdo->errorInfo());
			}
		}
	}

	//ログ記録
	freo_log(FREO_PLUGIN_RESPONSE_NAME . 'のセットアップを実行しました。');

	//完了画面へ移動
	freo_redirect('albumres/setup?exec=setup', true);

	return;
}

/* 管理画面 | アルバムレスポンス管理 */
function freo_page_albumres_admin()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['page']) or !preg_match('/^\d+$/', $_GET['page']) or $_GET['page'] < 1) {
		$_GET['page'] = 1;
	}

	//検索条件設定
	$condition = null;
	if (isset($_GET['word'])) {
		$condition .= ' AND text LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%') . ' OR name LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%');
	}
	if (isset($_GET['date'])) {
		if (preg_match('/^\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m%d\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m%d\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		}
	}
	if ($condition) {
		$condition = ' WHERE id IS NOT NULL ' . $condition;
	}

	//アルバムレスポンス取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses ' . $condition . ' ORDER BY id DESC LIMIT :start, :limit');
	$stmt->bindValue(':start', intval($freo->config['plugin']['albumres']['admin_limit']) * ($_GET['page'] - 1), PDO::PARAM_INT);
	$stmt->bindValue(':limit', intval($freo->config['plugin']['albumres']['admin_limit']), PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	$plugin_albumreses = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_albumreses[$data['id']] = $data;
	}

	//アルバムレスポンスID取得
	$plugin_albumres_keys = array_keys($plugin_albumreses);

	//アルバムレスポンス数・ページ数取得
	$stmt = $freo->pdo->query('SELECT COUNT(*) FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses ' . $condition);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$data                  = $stmt->fetch(PDO::FETCH_NUM);
	$plugin_albumres_count = $data[0];
	$plugin_albumres_page  = ceil($plugin_albumres_count / $freo->config['plugin']['albumres']['admin_limit']);


	//データ割当
	$freo->smarty->assign(array(
		'token'                 => freo_token('create'),
		'plugin_albumreses'      => $plugin_albumreses,
		'plugin_albumres_count' => $plugin_albumres_count,
		'plugin_albumres_page'  => $plugin_albumres_page,
	));

	return;
}

/* 管理画面 | アルバムレスポンス入力 */
function freo_page_albumres_admin_form()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		$_GET['id'] = 0;
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (!freo_token('check')) {
			$freo->smarty->append('errors', '不正なアクセスです。');
		}

		//入力データ検証
		if (!$freo->smarty->get_template_vars('errors')) {

			//名前
			if ($_POST['plugin_albumres']['name'] != '' and mb_strlen($_POST['plugin_albumres']['name'], 'UTF-8') > 200) {
				$freo->smarty->append('errors', '名前は200文字以内で入力してください。');
			}

			//本文
			if ($_POST['plugin_albumres']['text'] == '') {
				$freo->smarty->append('errors', '本文を入力してください。');
			} elseif (mb_strlen($_POST['plugin_albumres']['text'], 'UTF-8') > 5000) {
				$freo->smarty->append('errors', '本文は5000文字以内で入力してください。');
			}
		}

		//エラー確認
		if ($freo->smarty->get_template_vars('errors')) {
			//エラー表示
			$plugin_albumres = $_POST['plugin_albumres'];
		} else {
			$_SESSION['input'] = $_POST;

			//登録処理へ移動
			freo_redirect('albumres/admin_post?freo%5Btoken%5D=' . freo_token('create') . ($_GET['id'] ? '&id=' . $_GET['id'] : ''));
		}
	} else {
		if ($_GET['id']) {
			//編集データ取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses WHERE id = :id');
			$stmt->bindValue(':id', $_GET['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$plugin_albumres = $data;
			} else {
				freo_error('指定されたアルバムレスポンスが見つかりません。', '404 Not Found');
			}
		} else {
			//ユーザー取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'users WHERE id = :id');
			$stmt->bindValue(':id', $freo->user['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$user = $data;
			} else {
				freo_error('指定されたユーザーが見つかりません。', '404 Not Found');
			}

			//新規データ設定
			$plugin_albumres = array(
				'name' => $user['name'],
				'mail' => $user['mail'],
				'url'  => $user['url'],
			);
		}
	}

	//データ割当
	$freo->smarty->assign(array(
		'token' => freo_token('create'),
		'input' => array(
			'plugin_albumres' => $plugin_albumres
		)
	));

	return;
}

/* 管理画面 | アルバムレスポンス登録 */
function freo_page_albumres_admin_post()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//入力データ確認
	if (empty($_SESSION['input'])) {
		freo_redirect('albumres/admin?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('albumres/admin?error=1');
	}

	//入力データ取得
	$albumres = $_SESSION['input']['plugin_albumres'];

	if ($albumres['name'] == '') {
		$albumres['name'] = $freo->config['plugin']['albumres']['noname'];
	}
	if ($albumres['mail'] == '') {
		$albumres['mail'] = null;
	}
	if ($albumres['url'] == '') {
		$albumres['url'] = null;
	}
	if ($albumres['album_id'] == '') {
		$albumres['album_id'] = null;
	}
	if ($albumres['option01'] == '') {
		$albumres['option01'] = null;
	}
	if ($albumres['option02'] == '') {
		$albumres['option02'] = null;
	}
	if ($albumres['option03'] == '') {
		$albumres['option03'] = null;
	}
	if ($albumres['option04'] == '') {
		$albumres['option04'] = null;
	}
	if ($albumres['option05'] == '') {
		$albumres['option05'] = null;
	}
	if ($albumres['option06'] == '') {
		$albumres['option06'] = null;
	}
	if ($albumres['option07'] == '') {
		$albumres['option07'] = null;
	}
	if ($albumres['option08'] == '') {
		$albumres['option08'] = null;
	}
	if ($albumres['option09'] == '') {
		$albumres['option09'] = null;
	}
	if ($albumres['option10'] == '') {
		$albumres['option10'] = null;
	}
	if ($albumres['user_id'] == '') {
		$albumres['user_id'] = null;
	}
	if ($albumres['restriction'] == '') {
		$albumres['restriction'] = null;
	}

	//データ登録
	if (isset($_GET['id'])) {
		$stmt = $freo->pdo->prepare('UPDATE ' . FREO_DATABASE_PREFIX . 'plugin_albumreses SET modified = :now, name = :name, url = :url, mail = :mail, text = :text, album_id = :album_id, option01 = :option01, option02 = :option02, option03 = :option03, option04 = :option04, option05 = :option05, option06 = :option06, option07 = :option07, option08 = :option08, option09 = :option09, option10 = :option10, ip = :ip, user_id = :user_id, restriction = :restriction WHERE id = :id');
		$stmt->bindValue(':now',             date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',            $albumres['name']);
		$stmt->bindValue(':url',             $albumres['url']);
		$stmt->bindValue(':mail',            $albumres['mail']);
		$stmt->bindValue(':text',            $albumres['text']);
		$stmt->bindValue(':album_id',         $albumres['album_id']);
		$stmt->bindValue(':option01',        $albumres['option01']);
		$stmt->bindValue(':option02',        $albumres['option02']);
		$stmt->bindValue(':option03',        $albumres['option03']);
		$stmt->bindValue(':option04',        $albumres['option04']);
		$stmt->bindValue(':option05',        $albumres['option05']);
		$stmt->bindValue(':option06',        $albumres['option06']);
		$stmt->bindValue(':option07',        $albumres['option07']);
		$stmt->bindValue(':option08',        $albumres['option08']);
		$stmt->bindValue(':option09',        $albumres['option09']);
		$stmt->bindValue(':option10',        $albumres['option10']);
		$stmt->bindValue(':ip',              $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',         $albumres['user_id']);
		$stmt->bindValue(':restriction',     $albumres['restriction']);
		$stmt->bindValue(':id',              $albumres['id'], PDO::PARAM_INT);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
	} else {
		$stmt = $freo->pdo->prepare('INSERT INTO ' . FREO_DATABASE_PREFIX . 'plugin_albumreses VALUES(NULL, :now1, :now2, :name, :url, :mail, :text, :album_id, :option01, :option02, :option03, :option04, :option05, :option06, :option07, :option08, :option09, :option10, :ip, :user_id, :restriction)');
		$stmt->bindValue(':now1',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':now2',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',        $albumres['name']);
		$stmt->bindValue(':url',         $albumres['url']);
		$stmt->bindValue(':text',        $albumres['text']);
		$stmt->bindValue(':album_id',    $albumres['album_id']);
		$stmt->bindValue(':option01',    $albumres['option01']);
		$stmt->bindValue(':option02',    $albumres['option02']);
		$stmt->bindValue(':option03',    $albumres['option03']);
		$stmt->bindValue(':option04',    $albumres['option04']);
		$stmt->bindValue(':option05',    $albumres['option05']);
		$stmt->bindValue(':option06',    $albumres['option06']);
		$stmt->bindValue(':option07',    $albumres['option07']);
		$stmt->bindValue(':option08',    $albumres['option08']);
		$stmt->bindValue(':option09',    $albumres['option09']);
		$stmt->bindValue(':option10',    $albumres['option10']);
		$stmt->bindValue(':ip',          $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',     $albumres['user_id']);
		$stmt->bindValue(':restriction', $albumres['restriction']);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
		$albumres['id']           = $freo->pdo->lastInsertId();
	}

	//入力データ破棄
	$_SESSION['input'] = array();

	//ログ記録
	if (isset($_GET['id'])) {
		freo_log('アルバムレスポンスを編集しました。');
	} else {
		freo_log('アルバムレスポンスを新規に登録しました。');
	}

	//アルバムレスポンス管理へ移動
	if (isset($_GET['id'])) {
		freo_redirect('albumres/admin?exec=update&id=' . $albumres['id']);
	} else {
		freo_redirect('albumres/admin?exec=insert');
	}

	return;
}

/* 管理画面 | アルバムレスポンス入力 */
function freo_page_albumres_form()
{
	global $freo;

	//ログイン状態確認
	if ($freo->config['plugin']['albumres']['authority'] == 'user') {
		if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
			freo_redirect('login', true);
		}
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		$_GET['id'] = 0;
	}

	//リクエストメソッドに応じた処理を実行
	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		//ワンタイムトークン確認
		if (isset($_POST['plugin_album'])) {
			//パスワード認証
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albums WHERE id = :id AND restriction = \'password\' AND password = :password');
			$stmt->bindValue(':id',       $_GET['album_id'], PDO::PARAM_INT);
			$stmt->bindValue(':password', $_POST['plugin_album']['password']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$_SESSION['security']['plugin_album'][$_GET['album_id']] = true;

				freo_redirect('album/view/' . $_GET['album_id']);
			} else {
				freo_error('パスワードが違います。');
			}
		} else {
			//ワンタイムトークン確認
			if (!freo_token('check')) {
				$freo->smarty->append('errors', '不正なアクセスです。');
			}
		}


		//入力データ検証
		if (!$freo->smarty->get_template_vars('errors')) {
			//名前
			if ($_POST['plugin_albumres']['name'] != '' and mb_strlen($_POST['plugin_albumres']['name'], 'UTF-8') > 200) {
				$freo->smarty->append('errors', '名前は200文字以内で入力してください。');
			}
			//本文
			if ($_POST['plugin_albumres']['text'] == '') {
				$freo->smarty->append('errors', '本文を入力してください。');
			} elseif (mb_strlen($_POST['plugin_albumres']['text'], 'UTF-8') > 5000) {
				$freo->smarty->append('errors', '本文は5000文字以内で入力してください。');
			}
		}

		//エラー確認
		if ($freo->smarty->get_template_vars('errors')) {
			//エラー表示
			$plugin_albumres = $_POST['plugin_albumres'];
		} else {
			$_SESSION['input'] = $_POST;

			//登録処理へ移動
			freo_redirect('albumres/post?freo%5Btoken%5D=' . freo_token('create') . ($_GET['id'] ? '&id=' . $_GET['id'] : ''));
		}
	} else {

		if ($_GET['id']) {
			//ログイン状態確認
			if (!$freo->user['id']) {
				freo_redirect('login', true);
			}

			//権限確認
			if ($freo->user['authority'] != 'root') {
				$stmt = $freo->pdo->prepare('SELECT user_id FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses WHERE id = :id');
				$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
				$flag = $stmt->execute();
				if (!$flag) {
					freo_error($stmt->errorInfo());
				}

				if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
					if ($freo->user['id'] != $data['user_id']) {
						freo_error('この記事を編集する権限がありません。');
					}
				}
			}

			//編集データ取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses WHERE id = :id');
			$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$plugin_albumres = $data;
			} else {
				freo_error('指定されたアルバムレスポンスが見つかりません。');
			}
		} else {
			//ユーザー取得
			$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'users WHERE id = :id');
			$stmt->bindValue(':id', $freo->user['id']);
			$flag = $stmt->execute();
			if (!$flag) {
				freo_error($stmt->errorInfo());
			}

			if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
				$user = $data;
			}

			//新規データ設定
			if ($freo->user['id']) {
				$plugin_albumres = array(
					'name' => $user['name'],
					'mail' => $user['mail'],
					'url'  => $user['url'],
				);
			} else {
				$plugin_albumres = array();
			}
		}
	}

	//アルバムID取得
	$target_id = $_GET['album_id'];

	//アルバム取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albums WHERE id = :id');
	$stmt->bindValue(':id', $target_id);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	if ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_album = $data;
	} else {
		freo_error('指定されたアルバムが見つかりません。');
	}

	//アルバムタグ取得
	if ($plugin_album['tag']) {
		$plugin_album_tags = explode(',', $plugin_album['tag']);
	} else {
		$plugin_album_tags = array();
	}

	//表示順
	$sort = 0;
	if ($freo->config['plugin']['album']['album_file_sort'] = 'descend') {
		$sort = 1;
	}

	//アルバムファイル取得
	$plugin_album_files = array();

	$file_dir = FREO_FILE_DIR . 'plugins/album_files/' . $target_id . '/';
	$thumbnail_dir = FREO_FILE_DIR . 'plugins/album_thumbnails/' . $target_id . '/';

	if (file_exists($file_dir)) {
		if ($dir = scandir($file_dir, $sort)) {
			foreach ($dir as $data) {
				if (is_file($file_dir . $data) and preg_match("/(\w+)\.\w+$/", $data, $matches)) {
					list($width, $height, $size) = freo_file($file_dir . $data);
					if (is_file($thumbnail_dir . $data) and preg_match("/(\w+)\.\w+$/", $data, $matches)) {
						list($thumbnailwidth, $thumbnailheight, $thumbnailsize) = freo_file($thumbnail_dir . $data);
						$thumbnail = array(
							'name'    => $data,
							'width'   => $thumbnailwidth,
							'height'  => $thumbnailheight,
							'size'    => $thumbnailsize
						);
					} else {
						$thumbnail = array();
					}
					$plugin_album_files[$matches[1]] = array(
						'name'      => $data,
						'width'     => $width,
						'height'    => $height,
						'size'      => $size,
						'thumbnail' => $thumbnail
					);
				}
			}
		} else {
			freo_error('ファイル保存ディレクトリを開けません。');
		}
	}

	//アルバム関連データ取得
	$plugin_album_associates = freo_associate_plugin_album('get', array($target_id));
	$plugin_album_associate  = $plugin_album_associates[$target_id];

	//アルバムフィルター取得
	$plugin_album_filters = freo_filter_plugin_album('user', array($target_id));
	$plugin_album_filter  = $plugin_album_filters[$target_id];

	if ($plugin_album_filter) {
		$plugin_album['title']     = str_replace('[$title]', $plugin_album['title'], $freo->config['plugin']['album']['filter_title']);
		$plugin_album['file']      = null;
		$plugin_album_files        = null;
		$plugin_album['text']      = str_replace('[$text]', $plugin_album['text'], $freo->config['plugin']['album']['filter_text']);
	}

	//アルバム保護データ取得
	$plugin_album_securities = freo_security_plugin_album('user', array($target_id));
	$plugin_album_security   = $plugin_album_securities[$target_id];

	if ($plugin_album_security) {
		$plugin_album['title']     = str_replace('[$title]', $plugin_album['title'], $freo->config['plugin']['album']['restriction_title']);
		$plugin_album['file']      = null;
		$plugin_album_files        = null;
		$plugin_album['text']      = str_replace('[$text]', $plugin_album['text'], $freo->config['plugin']['album']['restriction_text']);
	}

	//カテゴリー取得
	$stmt = $freo->pdo->query('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_album_categories ORDER BY sort, id');
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$plugin_album_categories = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_album_categories[$data['id']] = $data;
	}

	//データ割当
	$freo->smarty->assign(array(
		'token' => freo_token('create'),
		'plugin_album'             => $plugin_album,
		'plugin_album_tags'        => $plugin_album_tags,
		'plugin_album_files'       => $plugin_album_files,
		'plugin_album_categories'  => $plugin_album_categories,
		'input' => array(
			'plugin_albumres' => $plugin_albumres,
		)
	));

	return;
}

/* 管理画面 | アルバムレスポンス登録 */
function freo_page_albumres_post()
{
	global $freo;

	//入力データ確認
	if (empty($_SESSION['input'])) {
		freo_redirect('albumres?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('albumres?error=1');
	}

	//入力データ取得
	$albumres = $_SESSION['input']['plugin_albumres'];

	if ($albumres['name'] == '') {
		$albumres['name'] = $freo->config['plugin']['albumres']['noname'];
	}
	if ($albumres['mail'] == '') {
		$albumres['mail'] = null;
	}
	if ($albumres['url'] == '') {
		$albumres['url'] = null;
	}
	if ($albumres['album_id'] == '') {
		$albumres['album_id'] = null;
	}
	if ($albumres['user_id'] == '') {
		$albumres['user_id'] = null;
	}
	if ($albumres['option01'] == '') {
		$albumres['option01'] = null;
	}
	if ($albumres['option02'] == '') {
		$albumres['option02'] = null;
	}
	if ($albumres['option03'] == '') {
		$albumres['option03'] = null;
	}
	if ($albumres['option04'] == '') {
		$albumres['option04'] = null;
	}
	if ($albumres['option05'] == '') {
		$albumres['option05'] = null;
	}
	if ($albumres['option06'] == '') {
		$albumres['option06'] = null;
	}
	if ($albumres['option07'] == '') {
		$albumres['option07'] = null;
	}
	if ($albumres['option08'] == '') {
		$albumres['option08'] = null;
	}
	if ($albumres['option09'] == '') {
		$albumres['option09'] = null;
	}
	if ($albumres['option10'] == '') {
		$albumres['option10'] = null;
	}
	if ($albumres['restriction'] == '') {
		$albumres['restriction'] = null;
	}

	//データ登録
	if (isset($_GET['id'])) {
		$stmt = $freo->pdo->prepare('UPDATE ' . FREO_DATABASE_PREFIX . 'plugin_albumreses SET modified = :now, name = :name, url = :url, mail = :mail, text = :text, album_id = :album_id, option01 = :option01, option02 = :option02, option03 = :option03, option04 = :option04, option05 = :option05, option06 = :option06, option07 = :option07, option08 = :option08, option09 = :option09, option10 = :option10, ip = :ip, user_id = :user_id, restriction = :restriction WHERE id = :id');
		$stmt->bindValue(':now',             date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',            $albumres['name']);
		$stmt->bindValue(':url',             $albumres['url']);
		$stmt->bindValue(':mail',            $albumres['mail']);
		$stmt->bindValue(':text',            $albumres['text']);
		$stmt->bindValue(':album_id',        $albumres['album_id']);
		$stmt->bindValue(':option01',        $albumres['option01']);
		$stmt->bindValue(':option02',        $albumres['option02']);
		$stmt->bindValue(':option03',        $albumres['option03']);
		$stmt->bindValue(':option04',        $albumres['option04']);
		$stmt->bindValue(':option05',        $albumres['option05']);
		$stmt->bindValue(':option06',        $albumres['option06']);
		$stmt->bindValue(':option07',        $albumres['option07']);
		$stmt->bindValue(':option08',        $albumres['option08']);
		$stmt->bindValue(':option09',        $albumres['option09']);
		$stmt->bindValue(':option10',        $albumres['option10']);
		$stmt->bindValue(':ip',              $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',         $albumres['user_id']);
		$stmt->bindValue(':restriction',     $albumres['restriction']);
		$stmt->bindValue(':id',              $albumres['id'], PDO::PARAM_INT);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
	} else {
		$stmt = $freo->pdo->prepare('INSERT INTO ' . FREO_DATABASE_PREFIX . 'plugin_albumreses VALUES(NULL, :now1, :now2, :name, :url, :mail, :text, :album_id, :option01, :option02, :option03, :option04, :option05, :option06, :option07, :option08, :option09, :option10, :ip, :user_id, :restriction)');
		$stmt->bindValue(':now1',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':now2',        date('Y-m-d H:i:s'));
		$stmt->bindValue(':name',        $albumres['name']);
		$stmt->bindValue(':url',         $albumres['url']);
		$stmt->bindValue(':mail',        $albumres['mail']);
		$stmt->bindValue(':text',        $albumres['text']);
		$stmt->bindValue(':album_id',     $albumres['album_id']);
		$stmt->bindValue(':option01',    $albumres['option01']);
		$stmt->bindValue(':option02',    $albumres['option02']);
		$stmt->bindValue(':option03',    $albumres['option03']);
		$stmt->bindValue(':option04',    $albumres['option04']);
		$stmt->bindValue(':option05',    $albumres['option05']);
		$stmt->bindValue(':option06',    $albumres['option06']);
		$stmt->bindValue(':option07',    $albumres['option07']);
		$stmt->bindValue(':option08',    $albumres['option08']);
		$stmt->bindValue(':option09',    $albumres['option09']);
		$stmt->bindValue(':option10',    $albumres['option10']);
		$stmt->bindValue(':ip',          $_SERVER['REMOTE_ADDR']);
		$stmt->bindValue(':user_id',     $albumres['user_id']);
		$stmt->bindValue(':restriction', $albumres['restriction']);
		$flag = $stmt->execute();
		if (!$flag) {
			freo_error($stmt->errorInfo());
		}
		$albumres['id']           = $freo->pdo->lastInsertId();
	}

	//入力データ破棄
	$_SESSION['input'] = array();

	//ログ記録
	if (isset($_GET['id'])) {
		freo_log('アルバムレスポンスを編集しました。');
	} else {
		freo_log('アルバムレスポンスを新規に登録しました。');
	}

	//アルバムレスポンス管理へ移動
	if (isset($_GET['id'])) {
		freo_redirect('album/view/' . $albumres['album_id'] . '?exec=albumres_update');
	} else {
		freo_redirect('album/view/' . $albumres['album_id'] . '?exec=albumres_insert');
	}

	return;
}

/* 管理画面 | アルバムレスポンス削除 */
function freo_page_albumres_admin_delete()
{
	global $freo;

	//ログイン状態確認
	if ($freo->user['authority'] != 'root' and $freo->user['authority'] != 'author') {
		freo_redirect('login', true);
	}

	//パラメータ検証
	if (!isset($_GET['id']) or !preg_match('/^\d+$/', $_GET['id']) or $_GET['id'] < 1) {
		freo_redirect('albumres/admin?error=1');
	}

	//ワンタイムトークン確認
	if (!freo_token('check')) {
		freo_redirect('albumres/admin?error=1');
	}

	//アルバムレスポンス削除
	$stmt = $freo->pdo->prepare('DELETE FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses WHERE id = :id');
	$stmt->bindValue(':id', $_GET['id'], PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	//連番リセット
	if (FREO_DATABASE_TYPE == 'mysql') {
		$stmt = $freo->pdo->query('ALTER TABLE ' . FREO_DATABASE_PREFIX . 'plugin_albumreses AUTO_INCREMENT = 0');
		if (!$stmt) {
			freo_error($freo->pdo->errorInfo());
		}
	}

	//ログ記録
	freo_log('アルバムレスポンスを削除しました。');

	//アルバムレスポンス管理へ移動
	freo_redirect('albumres/admin?exec=delete&id=' . $_GET['id']);

	return;
}

/* アルバムレスポンス一覧 */
function freo_page_albumres_default()
{
	global $freo;

	//パラメータ検証
	if (!isset($_GET['page']) or !preg_match('/^\d+$/', $_GET['page']) or $_GET['page'] < 1) {
		$_GET['page'] = 1;
	}

	//検索条件設定
	$condition = null;
	if (isset($_GET['word'])) {
		$condition .= ' AND text LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%') . ' OR name LIKE ' . $freo->pdo->quote('%' . $_GET['word'] . '%');
	}
	if (isset($_GET['date'])) {
		if (preg_match('/^\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		} elseif (preg_match('/^\d\d\d\d\d\d\d\d$/', $_GET['date'])) {
			if (FREO_DATABASE_TYPE == 'mysql') {
				$condition .= ' AND DATE_FORMAT(created, \'%Y%m%d\') = ' . $freo->pdo->quote($_GET['date']);
			} else {
				$condition .= ' AND STRFTIME(\'%Y%m%d\', created) = ' . $freo->pdo->quote($_GET['date']);
			}
		}
	}
	if ($condition) {
		$condition = ' WHERE id IS NOT NULL ' . $condition;
	}

	//アルバムレスポンス取得
	$stmt = $freo->pdo->prepare('SELECT * FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses ' . $condition . ' ORDER BY id DESC LIMIT :start, :limit');
	$stmt->bindValue(':start', intval($freo->config['plugin']['albumres']['admin_limit']) * ($_GET['page'] - 1), PDO::PARAM_INT);
	$stmt->bindValue(':limit', intval($freo->config['plugin']['albumres']['admin_limit']), PDO::PARAM_INT);
	$flag = $stmt->execute();
	if (!$flag) {
		freo_error($stmt->errorInfo());
	}

	$plugin_albumreses = array();
	while ($data = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$plugin_albumreses[$data['id']] = $data;
	}

	//アルバムレスポンスID取得
	$plugin_albumres_keys = array_keys($plugin_albumreses);

	//アルバムレスポンス保護データ取得
	$plugin_albumres_securities = freo_security_plugin_albumres('user', $plugin_albumres_keys);

	foreach ($plugin_albumres_securities as $id => $security) {
		if (!$security) {
			continue;
		}

		$plugin_albumreses[$id]['mail']    = NULL;
		$plugin_albumreses[$id]['url']     = NULL;
		$plugin_albumreses[$id]['name']    = str_replace('[$name]', $plugin_albumreses[$id]['name'], $freo->config['plugin']['albumres']['restriction_name']);
		$plugin_albumreses[$id]['text']    = str_replace('[$text]', $plugin_albumreses[$id]['text'], $freo->config['plugin']['albumres']['restriction_text']);

	}

	//アルバムレスポンス数・ページ数取得
	$stmt = $freo->pdo->query('SELECT COUNT(*) FROM ' . FREO_DATABASE_PREFIX . 'plugin_albumreses ' . $condition);
	if (!$stmt) {
		freo_error($freo->pdo->errorInfo());
	}

	$data                  = $stmt->fetch(PDO::FETCH_NUM);
	$plugin_albumres_count = $data[0];
	$plugin_albumres_page  = ceil($plugin_albumres_count / $freo->config['plugin']['albumres']['admin_limit']);


	//データ割当
	$freo->smarty->assign(array(
		'token'                 => freo_token('create'),
		'plugin_albumreses'      => $plugin_albumreses,
		'plugin_albumres_count' => $plugin_albumres_count,
		'plugin_albumres_page'  => $plugin_albumres_page,
	));

	return;
}

?>
